module Neo4jSpatial
    require 'httparty'
    require 'json'

    if ENV['NEO4J_URL']
      $base_url = "http://#{ENV["NEO4J_URL"].to_s.sub(/^https?\:\/\//, '')}/db/data/ext/SpatialPlugin/graphdb/"
    else
      $base_url = "http://localhost:7474/db/data/ext/SpatialPlugin/graphdb/"
    end

    ##
    # Adds an editable +layer+
    # Params:
    # +layer+:: 
    # +format+::
    def self.add_editable_layer(layer, format)
     response = HTTParty.post(("#{$base_url}addEditableLayer"), :body => {:layer => layer, :format => format}).parsed_response
    end

    ##
    # Adds an CLQ Dynamic +layer+ to the +master_layer+ using the given +name+ and +geometry+
    # Params:
    # +master_layer+:: 
    # +name+::
    # +geometry+::
    # +layer+::
    def self.add_clq_dynamic_layer(master_layer, name, geometry, layer)
      response = HTTParty.post(("#{$base_url}addCQLDynamicLayer"), :body => {:masterLayer => master_layer, :name => name, :geometry => geometry, :layer => layer}).parsed_response
    end

    ##
    # Finds geometries in the +layer+ within the given +distance_in_km+ to (+point_x+,+point_y+)
    # Params:
    # +point_x+:: 
    # +point_y+::
    # +distance_in_km+::
    # +layer+::
    def self.find_geometries_within_distance(point_x, point_y, distance_in_km, layer)
      response = HTTParty.get(("#{$base_url}findGeometriesWithinDistance"), :query => {:pointX => point_x, :pointY => point_y, :distanceInKm => distance_in_km, :layer => layer}).parsed_response
    end

    ##
    # 
    # Params:
    # +geometry+:: 
    # +node+::
    # +layer+::
    def self.update_geometry_from_wkt(geometry, node, layer)
      response = HTTParty.post(("#{$base_url}updateGeometryFromWKT"), :body => {:geometry => layer, :node =>  node, :layer => layer}).parsed_response
    end

    ##
    # 
    # Params:
    # +geometry+:: 
    # +layer+::
    def self.add_geometry_wkt_to_layer(geometry, layer)
      response = post(("http://#{$base_url}addGeometryWKTToLayer"), :body => {:geometry => geometry, :layer => layer}).parsed_response
    end

    ##
    # Gets the given +layer+
    # Params:
    # +layer+:: 
    def self.get_layer(layer)
      response = HTTParty.get(("#{$base_url}getLayer"), :query => {:layer => layer}).parsed_response
    end

    ##
    # Adds a simple point +layer+ with given +lat+ and +lon+
    # Params:
    # +layer+:: 
    # +lat+::
    # +lon+::
    def self.add_simple_point_layer(layer, lat, lon)
      response = HTTParty.post(("#{$base_url}addSimplePointLayer"), :body => {:layer => layer, :lat => lat, :lon => lon}).parsed_response
    end

    ##
    # 
    # Params:
    # +min_x+:: 
    # +max_x+::
    # +min_y+::
    # +max_x+::
    # +layer+::
    def self.find_geometries_in_b_box(min_x, max_x, min_y, max_y, layer)
      response = HTTParty.get(("#{$base_url}findGeometriesInBBox"), :query => {:minx => min_x, :maxx => max_x, :miny => min_y, :maxy => max_y, :layer => layer}).parsed_response
    end

    ##
    # Adds the given +node+ to the given +layer+
    # Params:
    # +node+:: 
    # +layer+::
    def self.add_node_to_layer(node, layer)
      response = HTTParty.post(("#{$base_url}addNodeToLayer"), :body => {:node => node, :layer => layer}).parsed_response
    end
end
